pyoptionchain
=============

Google Option Chain + Tk + Pandas DataFrame

Manual Installation
===================
::

	pip install -r requirements.txt
	./setup.py install

Installing Using PyPI
=====================
::

	pip install pyoptionchain

Running Test
============
::

	./tests.py

Running The App
===============
::

	pyoptionchain